       IDENTIFICATION DIVISION.
       PROGRAM-ID.    SIMOSTAT.
       AUTHOR.        SIMOTIME TECHNOLOGIES.
      *****************************************************************
      * Copyright (C) 1987-2019 SimoTime Technologies.                *
      *                                                               *
      * All rights reserved.  Unpublished, all rights reserved under  *
      * copyright law and international treaty.  Use of a copyright   *
      * notice is precautionary only and does not imply publication   *
      * or disclosure.                                                *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any non-commercial purpose and without fee is hereby      *
      * granted, provided the SimoTime copyright notice appear on all *
      * copies of the software. The SimoTime name or Logo may not be  *
      * used in any advertising or publicity pertaining to the use    *
      * of the software without the written permission of SimoTime    *
      * Technologies.                                                 *
      *                                                               *
      * Permission to use, copy, modify and distribute this software  *
      * for any commercial purpose requires a fee to be paid to       *
      * SimoTime Technologies. Once the fee is received by SimoTime   *
      * the latest version of the software will be delivered and a    *
      * license will be granted for use within an enterprise,         *
      * provided the SimoTime copyright notice appear on all copies   *
      * of the software. The SimoTime name or Logo may not be used    *
      * in any advertising or publicity pertaining to the use of the  *
      * software without the written permission of SimoTime           *
      * Technologies.                                                 *
      *                                                               *
      * SimoTime Technologies makes no warranty or representations    *
      * about the suitability of the software for any purpose. It is  *
      * provided "AS IS" without any expressed or implied warranty,   *
      * including the implied warranties of merchantability, fitness  *
      * for a particular purpose and non-infringement. SimoTime       *
      * Technologies shall not be liable for any direct, indirect,    *
      * special or consequential damages resulting from the loss of   *
      * use, data or projects, whether in an action of contract or    *
      * tort, arising out of or in connection with the use or         *
      * performance of this software                                  *
      *                                                               *
      * SimoTime Technologies                                         *
      * 15 Carnoustie Drive                                           *
      * Novato, CA 94949-5849                                         *
      * 415.883.6565                                                  *
      *                                                               *
      * RESTRICTED RIGHTS LEGEND                                      *
      * Use, duplication, or disclosure by the Government is subject  *
      * to restrictions as set forth in subparagraph (c)(1)(ii) of    *
      * the Rights in Technical Data and Computer Software clause at  *
      * DFARS 52.227-7013 or subparagraphs (c)(1) and (2) of          *
      * Commercial  Computer Software - Restricted Rights  at 48      *
      * CFR 52.227-19, as applicable.  Contact SimoTime Technologies, *
      * 15 Carnoustie Drive, Novato, CA 94949-5849.                   *
      *                                                               *
      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *                                                               *
      *****************************************************************
      *
      *****************************************************************
      * Source Member: SIMOSTAT.CBL
      * Copy Files:    PASSSTAT.CPY
      *                TAB4STAT.CPY
      *****************************************************************
      *
      * SIMOSTAT - Provide File Status information for displaying.
      *
      * CALLING PROTOCOL
      * ----------------
      * Use standard COBOL calling procedures.
      *
      * DESCRIPTION
      * -----------
      * This routine will use the two-byte File Status Code that may
      * be a mix of numeric and binary data to provide a four digit
      * File Status Code and a one-line description in the Pass Area.
      *
      ****************************************************************
      *
      * MAINTENANCE
      * -----------
      * 1989/02/27 Simmons, Created program.
      * 1989/02/27 Simmons, no changes to date
      *
      *****************************************************************
      *
       DATA DIVISION.
       WORKING-STORAGE SECTION.

      *****************************************************************
      * The following buffers are used to create a four-byte numeric  *
      * file status code that may be displayed.                       *
      *****************************************************************
       01  IO-STATUS.
           05  IO-STAT1            pic X.
           05  IO-STAT2            pic X.
       01  TWO-BYTES-BINARY        pic 9(4)  BINARY.
       01  TWO-BYTES-ALPHA         redefines TWO-BYTES-BINARY.
           05  TWO-BYTES-LEFT      pic X.
           05  TWO-BYTES-RIGHT     pic X.
       01  IO-STATUS-04.
           05  IO-STATUS-0401      pic 9     value 0.
           05  IO-STATUS-0403      pic 999   value 0.

       01  LOOK-OUT                pic X     value 'N'.

       COPY TAB4STAT.

      *****************************************************************
       LINKAGE SECTION.
       COPY PASSSTAT.

      *****************************************************************
       PROCEDURE DIVISION using FILE-STATUS-PASS-AREA.

           move FSPA-STATUS-CODE-02 to IO-STATUS
           perform CONVERT-TWO-BYTE-TO-FOUR-BYTE
           move IO-STATUS-04 to FSPA-STATUS-CODE-04

           perform GET-TEXT-VERBAGE

           GOBACK.

      *****************************************************************
      * Convert the two-byte file status code to a four digit value.  *
      * If the full two byte file status is numeric it will be        *
      * converted to 00nn. If the 1st byte is a numeric nine (9)      *
      * the second byte will be treated as a binary number and will   *
      * be converted to 9nnn.                                         *
      *****************************************************************
       CONVERT-TWO-BYTE-TO-FOUR-BYTE.
           if  IO-STATUS not NUMERIC
           or  IO-STAT1 = '9'
               move IO-STAT1 to IO-STATUS-04(1:1)
               subtract TWO-BYTES-BINARY from TWO-BYTES-BINARY
               move IO-STAT2 to TWO-BYTES-RIGHT
               add TWO-BYTES-BINARY to ZERO giving IO-STATUS-0403
           else
               move '0000' to IO-STATUS-04
               move IO-STATUS to IO-STATUS-04(3:2)
           end-if
           exit.

      *****************************************************************
       GET-TEXT-VERBAGE.
           add 1 to ZERO giving STATUS-IDX
           move 'N' to LOOK-OUT
           move SPACES to FSPA-TEXT-MESSAGE
           perform until STATUS-IDX > STATUS-CELLS-MAXIMUM
                      or LOOK-OUT = 'Y'
               if  STATUS-CELL-04(STATUS-IDX) = FSPA-STATUS-CODE-04
                   move STATUS-CELL(STATUS-IDX) to FSPA-TEXT-MESSAGE
                   move 'Y' to LOOK-OUT
               else
                   add 1 to STATUS-IDX
               end-if
           end-perform
           exit.

      *****************************************************************
      *      This program is provided by SimoTime Technologies        *
      *        Our e-mail address is: helpdesk@simotime.com           *
      *     Also, visit our Web Site at http://www.simotime.com       *
      *****************************************************************
